pub enum CpuExecutionContextError {
Initialization {
component: &'static str,
source: Arc<dyn Error + Send + Sync + 'static>,
},
Graph {
operation: &'static str,
source: Arc<dyn Error + Send + Sync + 'static>,
},
}Expand description
Error returned by explicit CPU context graph or eager-runtime operations.
The original tenferro diagnostic is retained as the error source.
Examples
use std::error::Error;
use std::sync::Arc;
use tensor4all_tensorbackend::CpuExecutionContextError;
let error = CpuExecutionContextError::Initialization {
component: "graph runtime",
source: Arc::new(std::io::Error::other("registration failed")),
};
assert!(error.source().is_some());Variants
Initialization
A context-owned graph or eager runtime could not be initialized.
Fields
Graph
Graph compilation or execution failed.