pub enum LogicalTensorError {
ShapeOverflow {
shape: Vec<usize>,
},
ElementCountMismatch {
shape: Vec<usize>,
expected: usize,
actual: usize,
},
Tensor {
operation: &'static str,
source: Error,
},
}Expand description
Error returned while validating, snapshotting, or reconstructing a logical tensor.
Variants
ShapeOverflow
The shape product overflowed usize.
ElementCountMismatch
The payload length does not match the shape.
Fields
Tensor
Tenferro could not read or construct the host tensor.