pub enum NativeTensorReadInput<'a> {
Borrowed(TensorRead<'a>),
Owned(Tensor),
}Expand description
Read-only native tensor input that can either borrow external payload data or own a temporary materialized tensor.
Variants
Borrowed(TensorRead<'a>)
Borrowed read-only tensor input.
Owned(Tensor)
Owned temporary tensor input.
Implementations