axpby_native_tensor

Function axpby_native_tensor 

pub fn axpby_native_tensor(
    lhs: &Tensor,
    a: &BackendScalar,
    rhs: &Tensor,
    b: &BackendScalar,
) -> Result<Tensor, BridgeError>
Compute a * lhs + b * rhs.

Errors

Returns an error when the native axpby fails (a shape or dtype mismatch, or a backend failure).