pub fn conj_native_tensor(tensor: &Tensor) -> Result<Tensor, BridgeError>Expand description
Conjugate a native tensor.
Errors
Returns an error when the native conjugation fails (a dtype mismatch or backend failure).
pub fn conj_native_tensor(tensor: &Tensor) -> Result<Tensor, BridgeError>Conjugate a native tensor.
Returns an error when the native conjugation fails (a dtype mismatch or backend failure).