full_piv_lu_backend

Function full_piv_lu_backend 

pub fn full_piv_lu_backend<T>(a: &TypedTensor<T>) -> Result<FullPivLuResult<T>>
Compute complete-pivoting LU with the configured tenferro backend.

Errors

Returns an error if the backend does not support the input dtype or if the factorization fails.