permute_native_tensor

Function permute_native_tensor 

pub fn permute_native_tensor(
    tensor: &Tensor,
    perm: &[usize],
) -> Result<Tensor, BridgeError>
Permute axes of a native tensor.

Errors

Returns an error when the native permutation fails (a shape or index mismatch, or a backend failure).