pub fn permute_storage_native(
storage: &Storage,
logical_dims: &[usize],
perm: &[usize],
) -> Result<Storage, BridgeError>Expand description
Permute storage by round-tripping through native tensors.
Errors
Returns an error when the native storage permutation fails (a shape or index mismatch, or a backend failure).