solve_backend

Function solve_backend 

pub fn solve_backend<T>(
    a: &TypedTensor<T>,
    b: &TypedTensor<T>,
) -> Result<TypedTensor<T>>
Solve A X = B with the configured tenferro backend.

Errors

Returns an error if the backend rejects the input shapes, the scalar dtype, or the coefficient matrix is singular.