pub fn sum_native_tensor(tensor: &Tensor) -> Result<BackendScalar, BridgeError>Expand description
Sum all elements of a native tensor, returning a dynamic scalar.
Errors
Returns an error when the native reduction fails (a backend or dtype mismatch failure).