pub struct FullPivLuResult<T: TensorScalar> { /* private fields */ }Expand description
Result of complete-pivoting LU decomposition P A Q^T = L U.
The parity output from tenferro is intentionally omitted because current
tensor4all callers only need the permutation matrices and the upper
triangular factor for pivot selection.
Implementations
Sourceimpl<T: TensorScalar> FullPivLuResult<T>
impl<T: TensorScalar> FullPivLuResult<T>
Sourcepub fn into_parts(
self,
) -> (TypedTensor<T>, TypedTensor<T>, TypedTensor<T>, TypedTensor<T>)
pub fn into_parts( self, ) -> (TypedTensor<T>, TypedTensor<T>, TypedTensor<T>, TypedTensor<T>)
Consume the decomposition into (P, L, U, Q).