pub struct SrcErrorEstimate {
pub error: f64,
pub norm: f64,
}Expand description
Small-matrix diagnostics produced by the successive randomized compression stopping estimator.
error is the Appendix C randomized residual estimate and norm is the
corresponding Frobenius norm estimate. Both values use the sketch width as
their normalization factor.
Examples
use tensor4all_tensorbackend::{src_error_estimate, Matrix};
let r = Matrix::from_col_major_vec(1, 1, vec![2.0_f64]);
let estimate = src_error_estimate(&r).unwrap();
assert!((estimate.error - 2.0).abs() < 1.0e-12);
assert!((estimate.norm - 2.0).abs() < 1.0e-12);Fields
error: f64Estimated residual magnitude from the inverse-adjoint QR factor.
norm: f64Estimated norm of the sketched tensor from the QR factor.