IncrementalQrScalar

Trait IncrementalQrScalar 

pub trait IncrementalQrScalar:
    BackendLinalgScalar
    + MatrixScalar
    + MatrixTriangularSolveScalar
    + ComplexFloat {
    // Required methods
    fn conjugate(self) -> Self;
    fn from_real(value: f64) -> Self;
}
Scalar operations required by IncrementalQr.

The implementation is provided for the two scalar types supported by the backend, f64 and Complex64. The conjugation hook keeps the update correct for complex matrices while using the same column-major algorithm for real matrices.

Examples

use tensor4all_tensorbackend::IncrementalQrScalar;
assert_eq!(<f64 as IncrementalQrScalar>::conjugate(2.0), 2.0);

Required Methods

fn conjugate(self) -> Self

Return the Hermitian conjugate of one scalar.

fn from_real(value: f64) -> Self

Convert a non-negative real norm into this scalar type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IncrementalQrScalar for Complex64

Source

fn conjugate(self) -> Self

Source

fn from_real(value: f64) -> Self

Source

impl IncrementalQrScalar for f64

Source

fn conjugate(self) -> Self

Source

fn from_real(value: f64) -> Self

Implementors