pub fn axpby_native_tensor(
lhs: &Tensor,
a: &BackendScalar,
rhs: &Tensor,
b: &BackendScalar,
) -> Result<Tensor, BridgeError>Expand description
Compute a * lhs + b * rhs.
Errors
Returns an error when the native axpby fails (a shape or dtype mismatch, or a backend failure).