pub fn axpby_storage_native(
lhs: &Storage,
lhs_dims: &[usize],
a: &BackendScalar,
rhs: &Storage,
rhs_dims: &[usize],
b: &BackendScalar,
) -> Result<Storage, BridgeError>Expand description
Compute a * lhs + b * rhs over storages via native tensors.
Errors
Returns an error when the native storage axpby fails (a shape or dtype mismatch, or a backend failure).