pub struct FullPivLuResult<T: TensorScalar> {
pub p: TypedTensor<T>,
pub l: TypedTensor<T>,
pub u: TypedTensor<T>,
pub q: TypedTensor<T>,
}Expand description
Result of complete-pivoting LU decomposition P A Q^T = L U.
The parity output from tenferro is intentionally omitted because current tensor4all callers only need the permutation matrices and the upper triangular factor for pivot selection.
Fields
p: TypedTensor<T>Left permutation matrix.
l: TypedTensor<T>Lower triangular factor.
u: TypedTensor<T>Upper triangular factor.
q: TypedTensor<T>Right permutation matrix.