pub trait IncrementalQrScalar:
BackendLinalgScalar
+ MatrixScalar
+ MatrixTriangularSolveScalar
+ ComplexFloat {
// Required methods
fn conjugate(self) -> Self;
fn from_real(value: f64) -> Self;
}Expand description
Scalar operations required by IncrementalQr.
The implementation is provided for the two scalar types supported by the
backend, f64 and Complex64. The conjugation hook keeps the update
correct for complex matrices while using the same column-major algorithm
for real matrices.
Examples
use tensor4all_tensorbackend::IncrementalQrScalar;
assert_eq!(<f64 as IncrementalQrScalar>::conjugate(2.0), 2.0);Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".